%{

/*
   cmd.l -- PIKT piktc command-line lexer

   $Header: /var/cvs/PIKT/pikt/src/piktc/cmd.l,v 1.54 2005/01/04 13:48:31 berto Exp $

   This file is part of PIKT ("Problem Informant/Killer Tool").
   Copyright (C) 1998,1999,2000,2001,2002,2003,2004,2005 by Robert Osterlund.

   PIKT is a trademark of the University of Chicago.  All Rights Reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   PIKT is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
   USA.

   Send problem reports, bouquets and brickbats to:  pikt-bugs@pikt.org
 */

#include "../lib/common.h"
#include "piktc.h"
#include "cmd.tab.h"

char _cmdlex_[] = "cmdlex";

#define RETURN(token) cmdlval.sval = mystrdup(yytext, _cmdlex_); return token

#undef YY_INPUT
#define YY_INPUT(buf, result, max_size)	{ \
		signed char c = cmdinput(); \
		result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
	}

#define CHKCONFLICT(A, B, FL)	if (FL) {\
					logreturn(OUTPUT, LOG_ERR, ERRID_CONFLICTING_OPTIONS, __FILE__, __LINE__, _cmdlex_, FALSE, "conflicting options: %s %s", A, B); \
					bailout = TRUE; \
				}

unsigned aoffset = 0;

char errmsg[MAXLINE+1];

char ALL[] = "+A all +P all +F all +O all +H all ";
int ii;

void cmderror(const char *);
signed int cmdinput(void);
void wrapstr(char **);
void unwrapstr(char **);

%}

W		[ \t]
nW		[^ \t]
D		[0-9]
L		[A-Za-z]
DL		[0-9A-Za-z]

%x mS pS DS ES CS AS PS FS OS HS

%option noyywrap

%%

<INITIAL,DS,ES,AS,PS,FS,OS,HS>"-"	{ BEGIN(mS);
					  return _MINUS;
					}
<INITIAL,DS,ES,AS,PS,FS,OS,HS>"+"	{ BEGIN(pS);
					  return _PLUS;
					}

<mS,pS>(A|S)f?			{ BEGIN(AS);
				  if (scanpass == 1) {
					CHKCONFLICT((yytext[0] == 'A' ? "+/-A" : "+/-S"), "-c", ischeck);
					CHKCONFLICT((yytext[0] == 'A' ? "+/-A" : "+/-S"), "-C", isdoublecheck);
					CHKCONFLICT((yytext[0] == 'A' ? "+/-A" : "+/-S"), "-h", ishelp);
					CHKCONFLICT((yytext[0] == 'A' ? "+/-A" : "+/-S"), "-V", isshow_version);
					if (yytext[1] == 'f')
						stripalm = FALSE;
					rcfbs |= (1L << ALMCFG);
					rcfbs |= (1L << ALTCFG);
					havecmditems = TRUE;
				  }
				  return _ALTOPT;  /* _SCTOPT */
				}

<mS>b				{ if (scanpass == 1) {
					isbackup = TRUE;
					CHKCONFLICT("-b", "-B", isrestore);
					CHKCONFLICT("-b", "-c", ischeck);
					CHKCONFLICT("-b", "-C", isdoublecheck);
					CHKCONFLICT("-b", "-d", isdisable);
					CHKCONFLICT("-b", "-f", isdiff);
					CHKCONFLICT("-b", "-h", ishelp);
					CHKCONFLICT("-b", "-k", iskill_piktd);
					CHKCONFLICT("-b", "-K", iskill_piktc_svc);
					CHKCONFLICT("-b", "-l", islist_files);
					CHKCONFLICT("-b", "-L", islist_items);
					CHKCONFLICT("-b", "-m", iscksum);
					CHKCONFLICT("-b", "-M", isexpand_macros);
					CHKCONFLICT("-b", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-b", "-s", isshow_status);
					CHKCONFLICT("-b", "-V", isshow_version);
					CHKCONFLICT("-b", "-w", isview_actual);
					CHKCONFLICT("-b", "-W", isview_auth);
					CHKCONFLICT("-b", "-x", isexecwait);
					CHKCONFLICT("-b", "-X", isexec);
					CHKCONFLICT("-b", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>B				{ if (scanpass == 1) {
					isrestore = TRUE;
					CHKCONFLICT("-B", "-b", isbackup);
					CHKCONFLICT("-B", "-c", ischeck);
					CHKCONFLICT("-B", "-C", isdoublecheck);
					CHKCONFLICT("-B", "-d", isdisable);
					CHKCONFLICT("-B", "-f", isdiff);
					CHKCONFLICT("-B", "-h", ishelp);
					CHKCONFLICT("-B", "-i", isinstall);
					CHKCONFLICT("-B", "-k", iskill_piktd);
					CHKCONFLICT("-B", "-K", iskill_piktc_svc);
					CHKCONFLICT("-B", "-l", islist_files);
					CHKCONFLICT("-B", "-L", islist_items);
					CHKCONFLICT("-B", "-m", iscksum);
					CHKCONFLICT("-B", "-M", isexpand_macros);
					CHKCONFLICT("-B", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-B", "-s", isshow_status);
					CHKCONFLICT("-B", "-t", isdelete);
					CHKCONFLICT("-B", "-V", isshow_version);
					CHKCONFLICT("-B", "-w", isview_actual);
					CHKCONFLICT("-B", "-W", isview_auth);
					CHKCONFLICT("-B", "-x", isexecwait);
					CHKCONFLICT("-B", "-X", isexec);
					CHKCONFLICT("-B", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>c|C				{ if (yytext[0] == 'c') {
					if (scanpass == 1) {
						CHKCONFLICT("-c", "-C", isdoublecheck);
						ischeck = TRUE;
					}
				  } else {
					if (scanpass == 1) {
						CHKCONFLICT("-C", "-c", ischeck);
						isdoublecheck = TRUE;
					}
				  }
				  if (scanpass == 1) {
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-b", isbackup);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-B", isrestore);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-d", isdisable);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-e", isenable);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-f", isdiff);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-h", ishelp);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-i", isinstall);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-k", iskill_piktd);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-K", iskill_piktc_svc);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-l", islist_files);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-L", islist_items);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-m", iscksum);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-M", isexpand_macros);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-p", isinstall_piktconf);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-r", isrestart_piktd);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-R", isrestart_piktc_svc);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-s", isshow_status);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-t", isdelete);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-V", isshow_version);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-w", isview_actual);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-W", isview_auth);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-x", isexecwait);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-X", isexec);
					CHKCONFLICT((yytext[0] == 'c' ? "-c" : "-C"), "-Z", islist_elements);
				  }
				  return _OPT;
				}

<pS>C|M				{ BEGIN(CS);
				  if (scanpass == 1) {
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-b", isbackup);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-B", isrestore);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-c", ischeck);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-C", isdoublecheck);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-d", isdisable);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-e", isenable);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-f", isdiff);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-h", ishelp);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-i", isinstall);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-k", iskill_piktd);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-K", iskill_piktc_svc);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-l", islist_files);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-L", islist_items);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-m", iscksum);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-p", isinstall_piktconf);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-r", isrestart_piktd);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-R", isrestart_piktc_svc);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-s", isshow_status);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-t", isdelete);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-V", isshow_version);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-w", isview_actual);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-W", isview_auth);
					CHKCONFLICT((yytext[0] == 'C' ? "+C" : "+M"), "-Z", islist_elements);
					havecmditems = TRUE;
				  }
				  return _CMDOPT;
				}

<mS>d				{ if (scanpass == 1) {
					isdisable = TRUE;
					CHKCONFLICT("-d", "-b", isbackup);
					CHKCONFLICT("-d", "-B", isrestore);
					CHKCONFLICT("-d", "-c", ischeck);
					CHKCONFLICT("-d", "-C", isdoublecheck);
					CHKCONFLICT("-d", "-e", isenable);
					CHKCONFLICT("-d", "-f", isdiff);
					CHKCONFLICT("-d", "-h", ishelp);
					CHKCONFLICT("-d", "-i", isinstall);
					CHKCONFLICT("-d", "-K", iskill_piktc_svc);
					CHKCONFLICT("-d", "-l", islist_files);
					CHKCONFLICT("-d", "-L", islist_items);
					CHKCONFLICT("-d", "-m", iscksum);
					CHKCONFLICT("-d", "-M", isexpand_macros);
					CHKCONFLICT("-d", "-p", isinstall_piktconf);
					CHKCONFLICT("-d", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-d", "-s", isshow_status);
					CHKCONFLICT("-d", "-V", isshow_version);
					CHKCONFLICT("-d", "-w", isview_actual);
					CHKCONFLICT("-d", "-W", isview_auth);
					CHKCONFLICT("-d", "-x", isexecwait);
					CHKCONFLICT("-d", "-X", isexec);
					CHKCONFLICT("-d", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS,pS>D			{ BEGIN(DS);
				  if (scanpass == 1) {
					CHKCONFLICT("+/-D", "-h", ishelp);
					CHKCONFLICT("+/-D", "-V", isshow_version);
					rcfbs |= (1L << DEFCFG);
				  }
				  return _DEFOPT;
				}

<mS>e				{ if (scanpass == 1) {
					isenable = TRUE;
					CHKCONFLICT("-e", "-b", isbackup);
					CHKCONFLICT("-e", "-B", isrestore);
					CHKCONFLICT("-e", "-c", ischeck);
					CHKCONFLICT("-e", "-C", isdoublecheck);
					CHKCONFLICT("-e", "-d", isdisable);
					CHKCONFLICT("-e", "-f", isdiff);
					CHKCONFLICT("-e", "-h", ishelp);
					CHKCONFLICT("-e", "-K", iskill_piktc_svc);
					CHKCONFLICT("-e", "-l", islist_files);
					CHKCONFLICT("-e", "-L", islist_items);
					CHKCONFLICT("-e", "-m", iscksum);
					CHKCONFLICT("-e", "-M", isexpand_macros);
					CHKCONFLICT("-e", "-p", isinstall_piktconf);
					CHKCONFLICT("-e", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-e", "-s", isshow_status);
					CHKCONFLICT("-e", "-t", isdelete);
					CHKCONFLICT("-e", "-V", isshow_version);
					CHKCONFLICT("-e", "-w", isview_actual);
					CHKCONFLICT("-e", "-W", isview_auth);
					CHKCONFLICT("-e", "-x", isexecwait);
					CHKCONFLICT("-e", "-X", isexec);
					CHKCONFLICT("-e", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS,pS>E			{ BEGIN(ES);
				  if (scanpass == 1) {
					CHKCONFLICT("+/-E", "-h", ishelp);
					CHKCONFLICT("+/-E", "-V", isshow_version);
				  }
				  return _ENVOPT;
				}

<mS>f				{ if (scanpass == 1) {
					isdiff = TRUE;
					CHKCONFLICT("-f", "-b", isbackup);
					CHKCONFLICT("-f", "-B", isrestore);
					CHKCONFLICT("-f", "-c", ischeck);
					CHKCONFLICT("-f", "-C", isdoublecheck);
					CHKCONFLICT("-f", "-d", isdisable);
					CHKCONFLICT("-f", "-e", isenable);
					CHKCONFLICT("-f", "-h", ishelp);
					CHKCONFLICT("-f", "-i", isinstall);
					CHKCONFLICT("-f", "-k", iskill_piktd);
					CHKCONFLICT("-f", "-K", iskill_piktc_svc);
					CHKCONFLICT("-f", "-l", islist_files);
					CHKCONFLICT("-f", "-L", islist_items);
					CHKCONFLICT("-f", "-m", iscksum);
					CHKCONFLICT("-f", "-M", isexpand_macros);
					CHKCONFLICT("-f", "-p", isinstall_piktconf);
					CHKCONFLICT("-f", "-r", isrestart_piktd);
					CHKCONFLICT("-f", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-f", "-s", isshow_status);
					CHKCONFLICT("-f", "-t", isdelete);
					CHKCONFLICT("-f", "-V", isshow_version);
					CHKCONFLICT("-f", "-w", isview_actual);
					CHKCONFLICT("-f", "-W", isview_auth);
					CHKCONFLICT("-f", "-x", isexecwait);
					CHKCONFLICT("-f", "-X", isexec);
					CHKCONFLICT("-f", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS,pS>(F)f?			{ BEGIN(FS);
				  if (scanpass == 1) {
					CHKCONFLICT("+/-F", "-c", ischeck);
					CHKCONFLICT("+/-F", "-C", isdoublecheck);
					CHKCONFLICT("+/-F", "-h", ishelp);
					CHKCONFLICT("+/-F", "-V", isshow_version);
					if (yytext[1] == 'f')
						stripfil = FALSE;
					rcfbs |= (1L << FILCFG);
					havecmditems = TRUE;
				  }
				  return _FILOPT;
				}

<mS>G				{ if (scanpass == 1)
					isdebug = TRUE;
				  return _OPT;
				}

<mS>h				{ if (scanpass == 1) {
					ishelp = TRUE;
					CHKCONFLICT("-h", "-b", isbackup);
					CHKCONFLICT("-h", "-B", isrestore);
					CHKCONFLICT("-h", "-c", ischeck);
					CHKCONFLICT("-h", "-C", isdoublecheck);
					CHKCONFLICT("-h", "-d", isdisable);
					CHKCONFLICT("-h", "-e", isenable);
					CHKCONFLICT("-h", "-f", isdiff);
					CHKCONFLICT("-h", "-i", isinstall);
					CHKCONFLICT("-h", "-I", isupdate_includes);
					CHKCONFLICT("-h", "-k", iskill_piktd);
					CHKCONFLICT("-h", "-K", iskill_piktc_svc);
					CHKCONFLICT("-h", "-l", islist_files);
					CHKCONFLICT("-h", "-L", islist_items);
					CHKCONFLICT("-h", "-m", iscksum);
					CHKCONFLICT("-h", "-M", isexpand_macros);
					CHKCONFLICT("-h", "-p", isinstall_piktconf);
					CHKCONFLICT("-h", "-r", isrestart_piktd);
					CHKCONFLICT("-h", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-h", "-s", isshow_status);
					CHKCONFLICT("-h", "-t", isdelete);
					CHKCONFLICT("-h", "-v", isverbose);
					CHKCONFLICT("-h", "-w", isview_actual);
					CHKCONFLICT("-h", "-W", isview_auth);
					CHKCONFLICT("-h", "-x", isexecwait);
					CHKCONFLICT("-h", "-X", isexec);
					CHKCONFLICT("-h", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS,pS>H			{ BEGIN(HS);
				  if (scanpass == 1) {
					CHKCONFLICT("+/-H", "-h", ishelp);
					CHKCONFLICT("+/-H", "-V", isshow_version);
					havecmdhosts = TRUE;
				  }
				  return _HSTOPT;
				}

<mS>i				{ if (scanpass == 1) {
					isinstall = TRUE;
					CHKCONFLICT("-i", "-B", isrestore);
					CHKCONFLICT("-i", "-c", ischeck);
					CHKCONFLICT("-i", "-C", isdoublecheck);
					CHKCONFLICT("-i", "-d", isdisable);
					CHKCONFLICT("-i", "-f", isdiff);
					CHKCONFLICT("-i", "-h", ishelp);
					CHKCONFLICT("-i", "-k", iskill_piktd);
					CHKCONFLICT("-i", "-K", iskill_piktc_svc);
					CHKCONFLICT("-i", "-l", islist_files);
					CHKCONFLICT("-i", "-L", islist_items);
					CHKCONFLICT("-i", "-m", iscksum);
					CHKCONFLICT("-i", "-M", isexpand_macros);
					CHKCONFLICT("-i", "-p", isinstall_piktconf);
					CHKCONFLICT("-i", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-i", "-s", isshow_status);
					CHKCONFLICT("-i", "-t", isdelete);
					CHKCONFLICT("-i", "-V", isshow_version);
					CHKCONFLICT("-i", "-w", isview_actual);
					CHKCONFLICT("-i", "-W", isview_auth);
					CHKCONFLICT("-i", "-x", isexecwait);
					CHKCONFLICT("-i", "-X", isexec);
					CHKCONFLICT("-i", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>I				{ if (scanpass == 1) {
					isupdate_includes = TRUE;
					CHKCONFLICT("-I", "-h", ishelp);
					CHKCONFLICT("-I", "-k", iskill_piktd);
					CHKCONFLICT("-I", "-K", iskill_piktc_svc);
					CHKCONFLICT("-I", "-p", isinstall_piktconf);
					CHKCONFLICT("-I", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-I", "-V", isshow_version);
				  }
				  return _OPT;
				}

<mS>k				{ if (scanpass == 1) {
					iskill_piktd = TRUE;
					CHKCONFLICT("-k", "-b", isbackup);
					CHKCONFLICT("-k", "-B", isrestore);
					CHKCONFLICT("-k", "-c", ischeck);
					CHKCONFLICT("-k", "-C", isdoublecheck);
					CHKCONFLICT("-k", "-f", isdiff);
					CHKCONFLICT("-k", "-h", ishelp);
					CHKCONFLICT("-k", "-i", isinstall);
					CHKCONFLICT("-k", "-I", isupdate_includes);
					CHKCONFLICT("-k", "-l", islist_files);
					CHKCONFLICT("-k", "-L", islist_items);
					CHKCONFLICT("-k", "-m", iscksum);
					CHKCONFLICT("-k", "-M", isexpand_macros);
					CHKCONFLICT("-k", "-p", isinstall_piktconf);
					CHKCONFLICT("-k", "-r", isrestart_piktd);
					CHKCONFLICT("-k", "-s", isshow_status);
					CHKCONFLICT("-k", "-V", isshow_version);
					CHKCONFLICT("-k", "-w", isview_actual);
					CHKCONFLICT("-k", "-W", isview_auth);
					CHKCONFLICT("-k", "-x", isexecwait);
					CHKCONFLICT("-k", "-X", isexec);
					CHKCONFLICT("-k", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>K				{ if (scanpass == 1) {
					iskill_piktc_svc = TRUE;
					CHKCONFLICT("-K", "-b", isbackup);
					CHKCONFLICT("-K", "-B", isrestore);
					CHKCONFLICT("-K", "-c", ischeck);
					CHKCONFLICT("-K", "-C", isdoublecheck);
					CHKCONFLICT("-K", "-d", isdisable);
					CHKCONFLICT("-K", "-e", isenable);
					CHKCONFLICT("-K", "-f", isdiff);
					CHKCONFLICT("-K", "-h", ishelp);
					CHKCONFLICT("-K", "-i", isinstall);
					CHKCONFLICT("-K", "-I", isupdate_includes);
					CHKCONFLICT("-K", "-l", islist_files);
					CHKCONFLICT("-K", "-L", islist_items);
					CHKCONFLICT("-K", "-m", iscksum);
					CHKCONFLICT("-K", "-M", isexpand_macros);
					CHKCONFLICT("-K", "-p", isinstall_piktconf);
					CHKCONFLICT("-K", "-r", isrestart_piktd);
					CHKCONFLICT("-K", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-K", "-s", isshow_status);
					CHKCONFLICT("-K", "-t", isdelete);
					CHKCONFLICT("-K", "-V", isshow_version);
					CHKCONFLICT("-K", "-w", isview_actual);
					CHKCONFLICT("-K", "-W", isview_auth);
					CHKCONFLICT("-K", "-x", isexecwait);
					CHKCONFLICT("-K", "-X", isexec);
					CHKCONFLICT("-K", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>l				{ if (scanpass == 1) {
					islist_files = TRUE;
					CHKCONFLICT("-l", "-b", isbackup);
					CHKCONFLICT("-l", "-B", isrestore);
					CHKCONFLICT("-l", "-c", ischeck);
					CHKCONFLICT("-l", "-C", isdoublecheck);
					CHKCONFLICT("-l", "-d", isdisable);
					CHKCONFLICT("-l", "-e", isenable);
					CHKCONFLICT("-l", "-f", isdiff);
					CHKCONFLICT("-l", "-h", ishelp);
					CHKCONFLICT("-l", "-i", isinstall);
					CHKCONFLICT("-l", "-k", iskill_piktd);
					CHKCONFLICT("-l", "-K", iskill_piktc_svc);
					CHKCONFLICT("-l", "-L", islist_items);
					CHKCONFLICT("-l", "-m", iscksum);
					CHKCONFLICT("-l", "-M", isexpand_macros);
					CHKCONFLICT("-l", "-p", isinstall_piktconf);
					CHKCONFLICT("-l", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-l", "-s", isshow_status);
					CHKCONFLICT("-l", "-V", isshow_version);
					CHKCONFLICT("-l", "-w", isview_actual);
					CHKCONFLICT("-l", "-W", isview_auth);
					CHKCONFLICT("-l", "-x", isexecwait);
					CHKCONFLICT("-l", "-X", isexec);
					CHKCONFLICT("-l", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>L				{ if (scanpass == 1) {
					islist_items = TRUE;
					CHKCONFLICT("-L", "-b", isbackup);
					CHKCONFLICT("-L", "-B", isrestore);
					CHKCONFLICT("-L", "-c", ischeck);
					CHKCONFLICT("-L", "-C", isdoublecheck);
					CHKCONFLICT("-L", "-d", isdisable);
					CHKCONFLICT("-L", "-e", isenable);
					CHKCONFLICT("-L", "-f", isdiff);
					CHKCONFLICT("-L", "-h", ishelp);
					CHKCONFLICT("-L", "-i", isinstall);
					CHKCONFLICT("-L", "-k", iskill_piktd);
					CHKCONFLICT("-L", "-K", iskill_piktc_svc);
					CHKCONFLICT("-L", "-l", islist_files);
					CHKCONFLICT("-L", "-m", iscksum);
					CHKCONFLICT("-L", "-M", isexpand_macros);
					CHKCONFLICT("-L", "-p", isinstall_piktconf);
					CHKCONFLICT("-L", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-L", "-s", isshow_status);
					CHKCONFLICT("-L", "-V", isshow_version);
					CHKCONFLICT("-L", "-w", isview_actual);
					CHKCONFLICT("-L", "-W", isview_auth);
					CHKCONFLICT("-L", "-x", isexecwait);
					CHKCONFLICT("-L", "-X", isexec);
					CHKCONFLICT("-L", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>M				{ if (scanpass == 1) {
					isexpand_macros = TRUE;
					CHKCONFLICT("-M", "-b", isbackup);
					CHKCONFLICT("-M", "-B", isrestore);
					CHKCONFLICT("-M", "-c", ischeck);
					CHKCONFLICT("-M", "-C", isdoublecheck);
					CHKCONFLICT("-M", "-d", isdisable);
					CHKCONFLICT("-M", "-e", isenable);
					CHKCONFLICT("-M", "-f", isdiff);
					CHKCONFLICT("-M", "-h", ishelp);
					CHKCONFLICT("-M", "-i", isinstall);
					CHKCONFLICT("-M", "-k", iskill_piktd);
					CHKCONFLICT("-M", "-K", iskill_piktc_svc);
					CHKCONFLICT("-M", "-l", islist_files);
					CHKCONFLICT("-M", "-L", islist_items);
					CHKCONFLICT("-M", "-m", iscksum);
					CHKCONFLICT("-M", "-p", isinstall_piktconf);
					CHKCONFLICT("-M", "-r", isrestart_piktd);
					CHKCONFLICT("-M", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-M", "-s", isshow_status);
					CHKCONFLICT("-M", "-t", isdelete);
					CHKCONFLICT("-M", "-V", isshow_version);
					CHKCONFLICT("-M", "-w", isview_actual);
					CHKCONFLICT("-M", "-W", isview_auth);
					CHKCONFLICT("-M", "-x", isexecwait);
					CHKCONFLICT("-M", "-X", isexec);
					CHKCONFLICT("-M", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>m[1-5]			{ if (scanpass == 1) {
					iscksum = atoi(yytext+1);
					CHKCONFLICT("-m", "-b", isbackup);
					CHKCONFLICT("-m", "-B", isrestore);
					CHKCONFLICT("-m", "-c", ischeck);
					CHKCONFLICT("-m", "-C", isdoublecheck);
					CHKCONFLICT("-m", "-d", isdisable);
					CHKCONFLICT("-m", "-e", isenable);
					CHKCONFLICT("-m", "-f", isdiff);
					CHKCONFLICT("-m", "-h", ishelp);
					CHKCONFLICT("-m", "-i", isinstall);
					CHKCONFLICT("-m", "-k", iskill_piktd);
					CHKCONFLICT("-m", "-K", iskill_piktc_svc);
					CHKCONFLICT("-m", "-l", islist_files);
					CHKCONFLICT("-m", "-L", islist_items);
					CHKCONFLICT("-m", "-M", isexpand_macros);
					CHKCONFLICT("-m", "-p", isinstall_piktconf);
					CHKCONFLICT("-m", "-r", isrestart_piktd);
					CHKCONFLICT("-m", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-m", "-s", isshow_status);
					CHKCONFLICT("-m", "-t", isdelete);
					CHKCONFLICT("-m", "-V", isshow_version);
					CHKCONFLICT("-m", "-w", isview_actual);
					CHKCONFLICT("-m", "-W", isview_auth);
					CHKCONFLICT("-m", "-x", isexecwait);
					CHKCONFLICT("-m", "-X", isexec);
					CHKCONFLICT("-m", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS,pS>(O)f?			{ BEGIN(OS);
				  if (scanpass == 1) {
					CHKCONFLICT("+/-O", "-c", ischeck);
					CHKCONFLICT("+/-O", "-C", isdoublecheck);
					CHKCONFLICT("+/-O", "-h", ishelp);
					CHKCONFLICT("+/-O", "-V", isshow_version);
					if (yytext[1] == 'f')
						stripobj = FALSE;
					rcfbs |= (1L << OBJCFG);
					havecmditems = TRUE;
				  }
				  return _OBJOPT;
				}

<mS>p				{ if (scanpass == 1) {
					isinstall_piktconf = TRUE;
					CHKCONFLICT("-p", "-B", isrestore);
					CHKCONFLICT("-p", "-c", ischeck);
					CHKCONFLICT("-p", "-C", isdoublecheck);
					CHKCONFLICT("-p", "-f", isdiff);
					CHKCONFLICT("-p", "-h", ishelp);
					CHKCONFLICT("-p", "-k", iskill_piktd);
					CHKCONFLICT("-p", "-K", iskill_piktc_svc);
					CHKCONFLICT("-p", "-l", islist_files);
					CHKCONFLICT("-p", "-L", islist_items);
					CHKCONFLICT("-p", "-m", iscksum);
					CHKCONFLICT("-p", "-M", isexpand_macros);
					CHKCONFLICT("-p", "-V", isshow_version);
					CHKCONFLICT("-p", "-w", isview_actual);
					CHKCONFLICT("-p", "-W", isview_auth);
					CHKCONFLICT("-p", "-x", isexecwait);
					CHKCONFLICT("-p", "-X", isexec);
					CHKCONFLICT("-p", "-Z", islist_elements);
				  }
				  if (scanpass == 1) {
					rcfbs |= (1L << MCRCFG);
					rcfbs |= (1L << FILCFG);
					havecmditems = TRUE;
					regname(&incmdfiles, "PIKT.conf", FALSE);
				  }
				  return _OPT;
				}

<mS,pS>(P)f?			{ BEGIN(PS);
				  if (scanpass == 1) {
					CHKCONFLICT("+/-P", "-c", ischeck);
					CHKCONFLICT("+/-P", "-C", isdoublecheck);
					CHKCONFLICT("+/-P", "-h", ishelp);
					CHKCONFLICT("+/-P", "-V", isshow_version);
					if (yytext[1] == 'f')
						stripprg = FALSE;
					rcfbs |= (1L << PRGCFG);
					havecmditems = TRUE;
				  }
				  return _PRGOPT;
				}

<mS>r				{ if (scanpass == 1) {
					isrestart_piktd = TRUE;
					CHKCONFLICT("-r", "-b", isbackup);
					CHKCONFLICT("-r", "-B", isrestore);
					CHKCONFLICT("-r", "-c", ischeck);
					CHKCONFLICT("-r", "-C", isdoublecheck);
					CHKCONFLICT("-r", "-f", isdiff);
					CHKCONFLICT("-r", "-h", ishelp);
					CHKCONFLICT("-r", "-k", iskill_piktd);
					CHKCONFLICT("-r", "-K", iskill_piktc_svc);
					CHKCONFLICT("-r", "-l", islist_files);
					CHKCONFLICT("-r", "-L", islist_items);
					CHKCONFLICT("-r", "-m", iscksum);
					CHKCONFLICT("-r", "-M", isexpand_macros);
					CHKCONFLICT("-r", "-p", isinstall_piktconf);
					CHKCONFLICT("-r", "-V", isshow_version);
					CHKCONFLICT("-r", "-w", isview_actual);
					CHKCONFLICT("-r", "-W", isview_auth);
					CHKCONFLICT("-r", "-x", isexecwait);
					CHKCONFLICT("-r", "-X", isexec);
					CHKCONFLICT("-r", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>R				{ if (scanpass == 1) {
					isrestart_piktc_svc = TRUE;
					CHKCONFLICT("-R", "-b", isbackup);
					CHKCONFLICT("-R", "-B", isrestore);
					CHKCONFLICT("-R", "-c", ischeck);
					CHKCONFLICT("-R", "-C", isdoublecheck);
					CHKCONFLICT("-R", "-d", isdisable);
					CHKCONFLICT("-R", "-e", isenable);
					CHKCONFLICT("-R", "-f", isdiff);
					CHKCONFLICT("-R", "-h", ishelp);
					CHKCONFLICT("-R", "-i", isinstall);
					CHKCONFLICT("-R", "-I", isupdate_includes);
					CHKCONFLICT("-R", "-K", iskill_piktc_svc);
					CHKCONFLICT("-R", "-l", islist_files);
					CHKCONFLICT("-R", "-L", islist_items);
					CHKCONFLICT("-R", "-m", iscksum);
					CHKCONFLICT("-R", "-M", isexpand_macros);
					CHKCONFLICT("-R", "-p", isinstall_piktconf);
					CHKCONFLICT("-R", "-s", isshow_status);
					CHKCONFLICT("-R", "-t", isdelete);
					CHKCONFLICT("-R", "-V", isshow_version);
					CHKCONFLICT("-R", "-w", isview_actual);
					CHKCONFLICT("-R", "-W", isview_auth);
					CHKCONFLICT("-R", "-x", isexecwait);
					CHKCONFLICT("-R", "-X", isexec);
					CHKCONFLICT("-R", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>s				{ if (scanpass == 1) {
					isshow_status = TRUE;
					CHKCONFLICT("-s", "-b", isbackup);
					CHKCONFLICT("-s", "-B", isrestore);
					CHKCONFLICT("-s", "-c", ischeck);
					CHKCONFLICT("-s", "-C", isdoublecheck);
					CHKCONFLICT("-s", "-d", isdisable);
					CHKCONFLICT("-s", "-e", isenable);
					CHKCONFLICT("-s", "-f", isdiff);
					CHKCONFLICT("-s", "-h", ishelp);
					CHKCONFLICT("-s", "-i", isinstall);
					CHKCONFLICT("-s", "-k", iskill_piktd);
					CHKCONFLICT("-s", "-K", iskill_piktc_svc);
					CHKCONFLICT("-s", "-l", islist_files);
					CHKCONFLICT("-s", "-L", islist_items);
					CHKCONFLICT("-s", "-m", iscksum);
					CHKCONFLICT("-s", "-M", isexpand_macros);
					CHKCONFLICT("-s", "-p", isinstall_piktconf);
					CHKCONFLICT("-s", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-s", "-t", isdelete);
					CHKCONFLICT("-s", "-V", isshow_version);
					CHKCONFLICT("-s", "-w", isview_actual);
					CHKCONFLICT("-s", "-W", isview_auth);
					CHKCONFLICT("-s", "-x", isexecwait);
					CHKCONFLICT("-s", "-X", isexec);
					CHKCONFLICT("-s", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>t				{ if (scanpass == 1) {
					isdelete = TRUE;
					CHKCONFLICT("-t", "-B", isrestore);
					CHKCONFLICT("-t", "-c", ischeck);
					CHKCONFLICT("-t", "-C", isdoublecheck);
					CHKCONFLICT("-t", "-e", isenable);
					CHKCONFLICT("-t", "-f", isdiff);
					CHKCONFLICT("-t", "-h", ishelp);
					CHKCONFLICT("-t", "-i", isinstall);
					CHKCONFLICT("-t", "-K", iskill_piktc_svc);
					CHKCONFLICT("-t", "-m", iscksum);
					CHKCONFLICT("-t", "-M", isexpand_macros);
					CHKCONFLICT("-t", "-p", isinstall_piktconf);
					CHKCONFLICT("-t", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-t", "-s", isshow_status);
					CHKCONFLICT("-t", "-V", isshow_version);
					CHKCONFLICT("-t", "-w", isview_actual);
					CHKCONFLICT("-t", "-W", isview_auth);
					CHKCONFLICT("-t", "-x", isexecwait);
					CHKCONFLICT("-t", "-X", isexec);
				  }
				  return _OPT;
				}

<mS>T				{ if (scanpass == 1) {
					istest = TRUE;
					/* isdebug = TRUE; */
				  }
				  return _OPT;
				}

<mS>v				{ if (scanpass == 1) {
					isverbose = TRUE;
					CHKCONFLICT("-v", "-h", ishelp);
					CHKCONFLICT("-v", "-V", isshow_version);
				  }
				  return _OPT;
				}

<mS>V				{ if (scanpass == 1) {
					isshow_version = TRUE;
					CHKCONFLICT("-V", "-b", isbackup);
					CHKCONFLICT("-V", "-B", isrestore);
					CHKCONFLICT("-V", "-c", ischeck);
					CHKCONFLICT("-V", "-C", isdoublecheck);
					CHKCONFLICT("-V", "-d", isdisable);
					CHKCONFLICT("-V", "-e", isenable);
					CHKCONFLICT("-V", "-f", isdiff);
					CHKCONFLICT("-V", "-i", isinstall);
					CHKCONFLICT("-V", "-I", isupdate_includes);
					CHKCONFLICT("-V", "-k", iskill_piktd);
					CHKCONFLICT("-V", "-K", iskill_piktc_svc);
					CHKCONFLICT("-V", "-l", islist_files);
					CHKCONFLICT("-V", "-L", islist_items);
					CHKCONFLICT("-V", "-m", iscksum);
					CHKCONFLICT("-V", "-M", isexpand_macros);
					CHKCONFLICT("-V", "-p", isinstall_piktconf);
					CHKCONFLICT("-V", "-r", isrestart_piktd);
					CHKCONFLICT("-V", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-V", "-s", isshow_status);
					CHKCONFLICT("-V", "-t", isdelete);
					CHKCONFLICT("-V", "-v", isverbose);
					CHKCONFLICT("-V", "-w", isview_actual);
					CHKCONFLICT("-V", "-W", isview_auth);
					CHKCONFLICT("-V", "-x", isexecwait);
					CHKCONFLICT("-V", "-X", isexec);
					CHKCONFLICT("-V", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>w				{ if (scanpass == 1) {
					isview_actual = TRUE;
					CHKCONFLICT("-w", "-b", isbackup);
					CHKCONFLICT("-w", "-B", isrestore);
					CHKCONFLICT("-w", "-c", ischeck);
					CHKCONFLICT("-w", "-C", isdoublecheck);
					CHKCONFLICT("-w", "-d", isdisable);
					CHKCONFLICT("-w", "-e", isenable);
					CHKCONFLICT("-w", "-h", ishelp);
					CHKCONFLICT("-w", "-i", isinstall);
					CHKCONFLICT("-w", "-k", iskill_piktd);
					CHKCONFLICT("-w", "-K", iskill_piktc_svc);
					CHKCONFLICT("-w", "-l", islist_files);
					CHKCONFLICT("-w", "-L", islist_items);
					CHKCONFLICT("-w", "-m", iscksum);
					CHKCONFLICT("-w", "-M", isexpand_macros);
					CHKCONFLICT("-w", "-p", isinstall_piktconf);
					CHKCONFLICT("-w", "-r", isrestart_piktd);
					CHKCONFLICT("-w", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-w", "-s", isshow_status);
					CHKCONFLICT("-w", "-t", isdelete);
					CHKCONFLICT("-w", "-V", isshow_version);
					CHKCONFLICT("-w", "-W", isview_auth);
					CHKCONFLICT("-w", "-x", isexecwait);
					CHKCONFLICT("-w", "-X", isexec);
					CHKCONFLICT("-w", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>W				{ if (scanpass == 1) {
					isview_auth = TRUE;
					CHKCONFLICT("-W", "-b", isbackup);
					CHKCONFLICT("-W", "-B", isrestore);
					CHKCONFLICT("-W", "-c", ischeck);
					CHKCONFLICT("-W", "-C", isdoublecheck);
					CHKCONFLICT("-W", "-d", isdisable);
					CHKCONFLICT("-W", "-e", isenable);
					CHKCONFLICT("-W", "-h", ishelp);
					CHKCONFLICT("-W", "-i", isinstall);
					CHKCONFLICT("-W", "-k", iskill_piktd);
					CHKCONFLICT("-W", "-K", iskill_piktc_svc);
					CHKCONFLICT("-W", "-l", islist_files);
					CHKCONFLICT("-W", "-L", islist_items);
					CHKCONFLICT("-W", "-m", iscksum);
					CHKCONFLICT("-W", "-M", isexpand_macros);
					CHKCONFLICT("-W", "-p", isinstall_piktconf);
					CHKCONFLICT("-W", "-r", isrestart_piktd);
					CHKCONFLICT("-W", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-W", "-s", isshow_status);
					CHKCONFLICT("-W", "-t", isdelete);
					CHKCONFLICT("-W", "-V", isshow_version);
					CHKCONFLICT("-W", "-w", isview_actual);
					CHKCONFLICT("-W", "-x", isexecwait);
					CHKCONFLICT("-W", "-X", isexec);
					CHKCONFLICT("-W", "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>x|X				{ if (yytext[0] == 'x') {
					if (scanpass == 1) {
						CHKCONFLICT("-x", "-X", isexec);
						isexecwait = TRUE;
					}
				  } else {
					if (scanpass == 1) {
						CHKCONFLICT("-X", "-x", isexecwait);
						isexec = TRUE;
					}
				  }
				  if (scanpass == 1) {
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-b", isbackup);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-B", isrestore);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-c", ischeck);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-C", isdoublecheck);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-d", isdisable);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-e", isenable);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-f", isdiff);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-h", ishelp);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-i", isinstall);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-k", iskill_piktd);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-K", iskill_piktc_svc);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-l", islist_files);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-L", islist_items);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-m", iscksum);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-M", isexpand_macros);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-p", isinstall_piktconf);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-r", isrestart_piktd);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-R", isrestart_piktc_svc);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-s", isshow_status);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-t", isdelete);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-V", isshow_version);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-w", isview_actual);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-W", isview_auth);
					CHKCONFLICT((yytext[0] == 'x' ? "-x" : "-X"), "-Z", islist_elements);
				  }
				  return _OPT;
				}

<mS>Z				{ if (scanpass == 1) {
					islist_elements = TRUE;
					CHKCONFLICT("-Z", "-b", isbackup);
					CHKCONFLICT("-Z", "-B", isrestore);
					CHKCONFLICT("-Z", "-c", ischeck);
					CHKCONFLICT("-Z", "-C", isdoublecheck);
					CHKCONFLICT("-Z", "-d", isdisable);
					CHKCONFLICT("-Z", "-e", isenable);
					CHKCONFLICT("-Z", "-f", isdiff);
					CHKCONFLICT("-Z", "-h", ishelp);
					CHKCONFLICT("-Z", "-i", isinstall);
					CHKCONFLICT("-Z", "-k", iskill_piktd);
					CHKCONFLICT("-Z", "-K", iskill_piktc_svc);
					CHKCONFLICT("-Z", "-l", islist_files);
					CHKCONFLICT("-Z", "-m", iscksum);
					CHKCONFLICT("-Z", "-M", isexpand_macros);
					CHKCONFLICT("-Z", "-p", isinstall_piktconf);
					CHKCONFLICT("-Z", "-R", isrestart_piktc_svc);
					CHKCONFLICT("-Z", "-s", isshow_status);
					CHKCONFLICT("-Z", "-V", isshow_version);
					CHKCONFLICT("-Z", "-w", isview_actual);
					CHKCONFLICT("-Z", "-W", isview_auth);
					CHKCONFLICT("-Z", "-x", isexecwait);
					CHKCONFLICT("-Z", "-X", isexec);
				  }
				  return _OPT;
				}

<mS,pS>{W}			{ BEGIN(INITIAL); }

<mS,pS>.			{ if (scanpass == 1) {	/* should never get
							   to scanpass 2
							 */
					sprintf(errmsg, "illegal option: %c", yytext[0]);
					cmderror(errmsg);
					bailout = TRUE;
				  }
				  return _OPT;
				}

<AS,PS,FS,OS,HS>all		{ return _ALL; }

<INITIAL>ALL			{ for (ii=strlen(ALL)-1; ii>=0; ii--)
					unput(ALL[ii]);
				}

<DS>{DL}{nW}*			{ RETURN(_DEFINE); }

<ES>{DL}[_0-9A-Za-z]*		{ RETURN(_ENVAR); }
<ES>=				{ return _EQ; }
<ES>\177[^\177]*\177		{ yytext[yyleng-1] = '\0';
				  cmdlval.sval = mystrdup(yytext+1, _cmdlex_);
				  return _ENVAL;
				}

<AS>{DL}{nW}*			{ RETURN(_ALERT); }
<AS>={DL}{nW}*			{ havecmdmacros[ALT] = TRUE;
				  RETURN(_ALERT);
				}

<PS>{DL}{nW}*			{ RETURN(_PROGRAM); }
<PS>={DL}{nW}*			{ havecmdmacros[PRG] = TRUE;
				  RETURN(_PROGRAM);
				}

<FS>{DL}{nW}*			{ RETURN(_MYFILE); }
<FS>={DL}{nW}*			{ havecmdmacros[FIL] = TRUE;
				  RETURN(_MYFILE);
				}

<OS>{DL}{nW}*			{ RETURN(_OBJECT); }
<OS>={DL}{nW}*			{ havecmdmacros[OBJ] = TRUE;
				  RETURN(_OBJECT);
				}

<HS>{DL}{nW}*			{ RETURN(_HOST); }

<CS>\177[^\177]*\177		{ yytext[yyleng-1] = '\0';
				  cmdlval.sval = mystrdup(yytext+1, _cmdlex_);
				  if (scanpass == 1) {
					/* we handle '\177' stripping above */
					inspectline(cmdlval.sval, &hasmacro, FALSE);
					if (hasmacro)
						rcfbs |= (1L << MCRCFG);
				  }
				  return _COMMAND;
				}

<CS>("-"|"+")[A-Z]		{ BEGIN(INITIAL);
				  yyless(0);
				}

<CS>{nW}+			{ if (scanpass == 1) {
					inspectline(yytext, &hasmacro, FALSE);
					if (hasmacro)
						rcfbs |= (1L << MCRCFG);
				  }
				  RETURN(_COMMAND);
				}

<DS,ES,CS,AS,PS,FS,OS,HS>{W}	{ ; }

<INITIAL,DS,ES,CS,AS,PS,FS,OS,HS>. { return yytext[0]; }

%%

/* cmd error handler
 */
void
cmderror (const char *message)
{

	logreturn(OUTPUT, LOG_ERR, ERRID_CMD_PARSE_ERROR, __FILE__, __LINE__, "cmdparse", FALSE, "%s: %s", message, yytext ? yytext : nullstring);
	bailout = TRUE;
	return;
}

/* feed command-line arguments to the lexer input stream
 */
signed int
cmdinput (void)
{
	register char c;

	if (argvcurr > argvlast)
		return(EOF);
	if (aoffset == 0) {	/* at beginning of new argv */
		if (strchr(*argvcurr, ' ') || strchr(*argvcurr, '\t'))
			wrapstr(argvcurr);
	}
	if ((c = (*argvcurr)[aoffset++]) != '\0')
		return(c);
	/* end of argument, unwrap() if necessary, then move on to next */
	if (**argvcurr == '\177')
		unwrapstr(argvcurr);
	argvcurr++;
	aoffset = 0;
	return(' ');
}

/* put a wrapper around the given string to signal to the lexer that this
   is a multi-part command string
 */
void
wrapstr (char **s)
{
	char *t;

	t = (char *) mymalloc((strlen(*s)+3) * sizeof(char), "wrapstr");
	sprintf(t, "%c%s%c", '\177', *s, '\177');
	*s = t;
	return;
}

/* undo the wrapping in wrapstr(), necessary because we scan the
   command line twice and must put things back as they were
 */
void
unwrapstr (char **s)
{
	char *t;

	t = mystrdup((*s)+1, "unwrapstr");
	*(t+strlen(*s)-2) = '\0';
	*s = t;
	return;
}
